/* Conner Ardman
 * CSE 154 Exploration Session
 * This script calls the quotes API to populate a quote and author on the page.
 */
(function() {

    // Global JSON object to contain quotes. This is a global to prevent
    // long waiting times.
    let json;

    window.addEventListener("load", initialize);

    /**
     * When the page loads, call the API to populate the page with the first quote.
     */
    function initialize() {
       $("change").onclick = updatePage;
       let url = "/api";
       fetch(url)
          .then(checkStatus)
          .then(JSON.parse)
          .then(function(response) {
             json = response;
             updatePage();
          })
          .catch(alert);
    }

    /**
     * Choose a random quote and author and append them to the page.
     */
    function updatePage() {
        let quote = $("quote");
        let author = $("author");
        let choice = json[Math.floor(Math.random() * json.length)];
        quote.innerHTML = "Quote: " + choice["Quote"];
        author.innerHTML = "Author: " + choice["Author"];
    }

    // Shorthand function for document.getElementById
    function $(id) {
        return document.getElementById(id);
    }

     /** Helper function to return the response's result text if successful, otherwise
      * returns the rejected Promise result with an error status and corresponding text
      * @param {object} response - response to check for success/error
      * @return {object} - valid result text if response was successful, otherwise rejected
      *                    Promise result
      */
    function checkStatus(response) {
        if (response.status >= 200 && response.status < 300 || response.status == 0) {
            return response.text();
        } else {
            return Promise.reject(new Error(response.status + ": " + response.statusText));
        }
    }
})();
